==> Spec-Recorder%20Ver.1.11.zip: Spec-Recorder Ver.1.11/make_csv.py <==
# -*- coding: utf-8 -*-
from PIL import Image
#import datetime
import sys
#import os
import time
import csv
import libhro

#global img

argvs = sys.argv
#if len(argvs) != 2:
#	print "Error this program require two argment"
#	exit()
	
filetime = ""
filename = ""
#filetime = "1306140505"
#argvs = ["-a", filetime]
#filename = filetime + ".png"
#pos = (2500,35)
#open_image(filename)
#img = Image.open(filename)
strength_list = []
analyze_return = ()
#8,16,25,33,41,49,58,66,74,82,90,99,107,115,123,132,140,148,156,165,173,181,189,197,206,214,222,230,239,247

if argvs[1] == "-a":
	filetime = argvs[2]
	libhro.read_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list)
	writetxt = open(filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
	
if argvs[1] == "-c":
	print 1
	filename = argvs[2] + ".png"
	filetime = argvs[2]
	img = Image.open("./PNG/" + filename)
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	
if argvs[1] == "-ac":
	filetime = argvs[2]
	filename = argvs[2] + ".png"
	img = Image.open("./PNG/" + filename)
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list)
	writetxt = open(filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
	
#strength_list = make_list()
#read_csv(strength_list, filetime)
#print strength_list
#print len(strength_list)
#write_csv(strength_list, filetime)
#analyze_return = analyze(strength_list)
exit()

==> Spec-Recorder%20Ver.1.12.zip: Spec-Recorder Ver.1.12/make_csv.py <==
# -*- coding: utf-8 -*-
from PIL import Image
#import datetime
import sys
#import os
import time
import csv
import libhro

#global img

argvs = sys.argv
#if len(argvs) != 2:
#	print "Error this program require two argment"
#	exit()
	
filetime = ""
filename = ""
#filetime = "1306140505"
#argvs = ["-a", filetime]
#filename = filetime + ".png"
#pos = (2500,35)
#open_image(filename)
#img = Image.open(filename)
strength_list = []
analyze_return = ()
#8,16,25,33,41,49,58,66,74,82,90,99,107,115,123,132,140,148,156,165,173,181,189,197,206,214,222,230,239,247

if argvs[1] == "-a":
	filetime = argvs[2]
	libhro.read_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
	
if argvs[1] == "-c":
	print 1
	filename = argvs[2] + ".png"
	filetime = argvs[2]
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	
if argvs[1] == "-ac":
	filetime = argvs[2]
	filename = argvs[2] + ".png"
	img = Image.open("./monoPNG/" + filename[:])
	strength_list = libhro.make_list(img)
	libhro.write_csv(strength_list, filetime)
	analyze_return = libhro.analyze(strength_list)
	writetxt = open("./echo/" + filetime + '.echo', 'w')
	writetxt.write(str(analyze_return)[1:-1])
	writetxt.close() 
	
#strength_list = make_list()
#read_csv(strength_list, filetime)
#print strength_list
#print len(strength_list)
#write_csv(strength_list, filetime)
#analyze_return = analyze(strength_list)
exit()
